package admin

import (
	"net/http"

	"github.com/jmoiron/sqlx"
	"github.com/sirupsen/logrus"
	"gitlab.quimbo.fr/odwrtw/canape-sql/src/internal/web"
)

const (
	moviesCountQuery   = `SELECT COUNT(*) FROM movies;`
	showsCountQuery    = `SELECT COUNT(*) FROM shows;`
	episodesCountQuery = `SELECT COUNT(*) FROM episodes;`
)

// GetCount gets the count from a query
func GetCount(db *sqlx.DB, query string) (int, error) {
	var count int
	err := db.QueryRow(query).Scan(&count)
	if err != nil {
		return 0, err
	}
	return count, nil
}

// GetStatsHandler returns the stats of the app
func GetStatsHandler(env *web.Env, w http.ResponseWriter, r *http.Request) error {
	log := env.Log.WithFields(logrus.Fields{
		"function": "admin.GetStatsHandler",
	})

	log.Debug("getting stats")

	stats := struct {
		MoviesCount   int `json:"movies_count"`
		ShowsCount    int `json:"shows_count"`
		EpisodesCount int `json:"episodes_count"`
	}{}

	for _, s := range []struct {
		query string
		ptr   *int
	}{
		{moviesCountQuery, &stats.MoviesCount},
		{showsCountQuery, &stats.ShowsCount},
		{episodesCountQuery, &stats.EpisodesCount},
	} {
		var err error
		*s.ptr, err = GetCount(env.Database, s.query)
		if err != nil {
			return err
		}
	}

	return env.RenderJSON(w, stats)
}
